YANG Derived Data Type Support + Change in YANG Parser Grammar to 
Support String values which are not in double quotes with UT case + 
Addition of Revision Date Validation with UT case + Removal of 
String.valueOf

Change-Id: Ic152265a35c0d2b0f84473a94ca67681cf8efca8
diff --git a/utils/yangutils/src/test/java/org/onosproject/yangutils/parser/impl/listeners/ContactListenerTest.java b/utils/yangutils/src/test/java/org/onosproject/yangutils/parser/impl/listeners/ContactListenerTest.java
index 9791ba3..cb7bedb 100644
--- a/utils/yangutils/src/test/java/org/onosproject/yangutils/parser/impl/listeners/ContactListenerTest.java
+++ b/utils/yangutils/src/test/java/org/onosproject/yangutils/parser/impl/listeners/ContactListenerTest.java
@@ -47,7 +47,7 @@
 
         YangNode node = manager.getDataModel("src/test/resources/ContactValidEntry.yang");
 
         // Checks for the version value in data model tree.
         assertThat(((YangModule) node).getContact(), is("\"WG List:  <mailto:spring@ietf.org>\nEditor:    "
                 + "Stephane Litkowski\n           " + "<mailto:stephane.litkowski@orange.com>\""));
     }
@@ -63,6 +63,18 @@
     }
 
     /**
+     * Checks that contact can have a string value without double quotes.
+     */
+    @Test
+    public void processContactWithoutQuotes() throws IOException, ParserException {
+
+        YangNode node = manager.getDataModel("src/test/resources/ContactWithoutQuotes.yang");
+
+        // Checks for the contact value in data model tree.
+        assertThat(((YangModule) node).getContact(), is("WG"));
+    }
+
+    /**
      * Checks if contact is not empty.
      */
     @Test(expected = ParserException.class)
@@ -47,7 +47,7 @@
         YangNode node = manager.getDataModel("src/test/resources/ContactValidEntry.yang");
 
-        // Checks for the version value in data model tree.
+        // Checks for the contact value in data model tree.
         assertThat(((YangModule) node).getContact(), is("\"WG List:  <mailto:spring@ietf.org>\nEditor:    "
                 + "Stephane Litkowski\n           " + "<mailto:stephane.litkowski@orange.com>\""));